# Yamcs Client Library for Python
[![PyPI](https://img.shields.io/pypi/v/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/yamcs-client.svg)](https://pypi.python.org/pypi/yamcs-client/)


## Features

* MDB retrieval
* Telemetry updates
* Command History updates
* Alarm updates
* Event updates
* Archive retrieval
* Histogram retrieval


## Installation

Install with pip

    pip install yamcs-client


## License

LGPL-3.0. See [LICENSE](https://github.com/yamcs/python-yamcs-client/blob/master/LICENSE)
